@@ -27,8 +27,8 @@ use lib "@INSTALLARCHLIB@";
 ##    The latest release can be found on
 ##    http://www.engelschall.com/sw/slice/
 ##  
-##    Copyright (c) 1997-2000 Ralf S. Engelschall.
-##    Copyright (c) 1999-2000 Denis Barbier.
+##    Copyright (c) 1997-2002 Ralf S. Engelschall.
+##    Copyright (c) 1999-2002 Denis Barbier.
 ##  
 ##    This program is free software; it may be redistributed and/or modified only
 ##    under the terms of the GNU General Public License, which may be found in the
@@ -57,10 +57,10 @@ require "slice_pass2.pl";
 require "slice_pass3.pl";
 
 $CFG = {};
-&setup($CFG);
-&pass1($CFG);
-&pass2($CFG);
-&pass3($CFG);
+setup($CFG);
+pass1($CFG);
+pass2($CFG);
+pass3($CFG);
 
 exit(0);
 
