@@ -1,7 +1,7 @@
 ##
 ##  slice_pass1.pl -- Pass 1
-##  Copyright (c) 1997-2000 Ralf S. Engelschall.
-##  Copyright (c) 1999-2000 Denis Barbier.
+##  Copyright (c) 1997-2002 Ralf S. Engelschall.
+##  Copyright (c) 1999-2002 Denis Barbier.
 ##
 
 package main;
@@ -18,7 +18,7 @@ sub pass1 {
     my (@CURRENT_SLICE_NAMES, %CURRENT_LEVEL_BRAIN, $CURRENT_LEVEL_SET);
     my ($INPUT, $prolog, $pos, $inputpos, $prev, $name, $namex, $L, $open);
 
-    &verbose("\nPass 1: Determine delimiters\n\n");
+    verbose("\nPass 1: Determine delimiters\n\n");
 
     @CURRENT_SLICE_NAMES = ();
     %CURRENT_LEVEL_BRAIN = ();
@@ -68,7 +68,7 @@ sub pass1 {
             $pos  += length($prolog);
             $prev  = $inputpos;
 
-            $L = &alloclevel();                 # allocate next free level
+            $L = alloclevel();                 # allocate next free level
 
             push(@CURRENT_SLICE_NAMES, $name);  # remember name  for end delimiter
             $CURRENT_LEVEL_BRAIN{"$name"} .= ":$L";# remember level for end delimiter
@@ -85,7 +85,7 @@ sub pass1 {
             $CFG->{SLICE}->{MAXLEVEL} = ($CFG->{SLICE}->{MAXLEVEL} < $L ?
                                          $L : $CFG->{SLICE}->{MAXLEVEL});
 
-            &verbose("    slice `$name': begin at $pos, level $L\n");
+            verbose("    slice `$name': begin at $pos, level $L\n");
 
             $open++;
         }
@@ -109,12 +109,12 @@ sub pass1 {
             $CURRENT_LEVEL_BRAIN{"$name"} =~ s|:(\d+)$||; # take remembered level
             $L = $1;
 
-            &clearlevel($L);                         # de-allocate level
+            clearlevel($L);                         # de-allocate level
 
             # now end entry with :END
             $CFG->{SLICE}->{SET}->{ASC}->{"$name:$L"} .= ":$pos";
 
-            &verbose("    slice `$name': end at $pos, level $L\n");
+            verbose("    slice `$name': end at $pos, level $L\n");
 
             $pos++;
             $open--;
@@ -137,7 +137,7 @@ sub pass1 {
                 }
             }
         }
-        &error("Some slices were not closed:$err\n");
+        error("Some slices were not closed:$err\n");
     }
 }
 
