@@ -1,7 +1,7 @@
 ##
 ##  slice_pass2.pl -- Pass 2
-##  Copyright (c) 1997-2000 Ralf S. Engelschall. 
-##  Copyright (c) 1999-2000 Denis Barbier.
+##  Copyright (c) 1997-2002 Ralf S. Engelschall. 
+##  Copyright (c) 1999-2002 Denis Barbier.
 ##
 
 package main;
@@ -17,7 +17,7 @@ sub pass2 {
 
     my ($n, $asc, $slice, $set, $setA);
 
-    &verbose("\nPass 2: Calculation of slice sets\n\n");
+    verbose("\nPass 2: Calculation of slice sets\n\n");
 
     #  convert ASCII set representation string into internal set object
     sub asc2set {
@@ -58,7 +58,7 @@ sub pass2 {
     foreach $slice (keys(%{$CFG->{SLICE}->{SET}->{ASC}})) {
         $asc = $CFG->{SLICE}->{SET}->{ASC}->{$slice};
         $set->Empty();
-        &asc2set($asc, $set);
+        asc2set($asc, $set);
         $CFG->{SLICE}->{SET}->{OBJ}->{$slice} = $set->Clone();
     }
 
@@ -72,7 +72,7 @@ sub pass2 {
         $set->Empty();
         foreach $slice (keys(%{$CFG->{SLICE}->{SET}->{ASC}})) {
             $asc = $CFG->{SLICE}->{SET}->{ASC}->{$slice};
-            &asc2set($asc, $set, $i, 1); # load $set with entries of level $i
+            asc2set($asc, $set, $i, 1); # load $set with entries of level $i
             $setA->Union($setA, $set);   # add to $setA these entries
         }
         $CFG->{SLICE}->{SET}->{OBJ}->{"DEF$i"} = $set->Clone();
@@ -88,7 +88,7 @@ sub pass2 {
     foreach $slice (keys(%{$CFG->{SLICE}->{SET}->{ASC}})) {
         $asc = $CFG->{SLICE}->{SET}->{ASC}->{$slice};
         $set->Empty();
-        &asc2set($asc, $set);
+        asc2set($asc, $set);
         $L = $CFG->{SLICE}->{MINLEVELS}->{$slice};
         for ($i = $L+1; $i <= $CFG->{SLICE}->{MAXLEVEL}; $i++) {
             $set->Difference($set, $CFG->{SLICE}->{SET}->{OBJ}->{"DEF$i"});
@@ -100,10 +100,10 @@ sub pass2 {
         foreach $slice (sort(keys(%{$CFG->{SLICE}->{SET}->{OBJ}}))) {
             $set = $CFG->{SLICE}->{SET}->{OBJ}->{$slice};
             if ($set->Norm > 0) {
-                &verbose("    slice `$slice': " . $set->to_ASCII() . "\n");
+                verbose("    slice `$slice': " . $set->to_ASCII() . "\n");
             }
             else {
-                &verbose("    slice `$slice': -Empty-\n");
+                verbose("    slice `$slice': -Empty-\n");
             }
         }
     }
