@@ -1,7 +1,7 @@
 ##
 ##  slice_setup.pl -- Command line parsing and CFG setup
-##  Copyright (c) 1997-2000 Ralf S. Engelschall. 
-##  Copyright (c) 1999-2000 Denis Barbier.
+##  Copyright (c) 1997-2002 Ralf S. Engelschall. 
+##  Copyright (c) 1999-2002 Denis Barbier.
 ##
 
 package main;
@@ -11,6 +11,7 @@ sub usage {
     print STDERR "\n";
     print STDERR "Options:\n";
     print STDERR "  -o, --outputfile=FILESPEC  create output file(s)\n";
+    print STDERR "  -y, --output-policy=STRING set default output policy\n";
     print STDERR "  -v, --verbose              enable verbose mode\n";
     print STDERR "  -V, --version              display version string\n";
     print STDERR "  -h, --help                 display usage page\n";
@@ -29,8 +30,8 @@ sub usage {
 sub hello {
     print STDERR "$slice_version->{v_tex}\n";
     print STDERR <<'EOT';
-Copyright (c) 1997-2000 Ralf S. Engelschall. 
-Copyright (c) 1999-2000 Denis Barbier.
+Copyright (c) 1997-2002 Ralf S. Engelschall. 
+Copyright (c) 1999-2002 Denis Barbier.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -47,22 +48,28 @@ sub setup {
     $opt_h = 0;
     $opt_V = 0;
     $opt_v = 0;
+    $opt_y = '';
     @opt_o = ();
+    my (@options_list) = (
+        "v|verbose",
+        "V|version",
+        "h|help",
+        "o|outputfile=s@",
+        "y|output-policy=s",
+    );
     $SIG{'__WARN__'} = sub { 
         print STDERR "Slice:Error: $_[0]";
     };
+
     $Getopt::Long::bundling = 1;
     $Getopt::Long::getopt_compat = 0;
-    if (not Getopt::Long::GetOptions("v|verbose",
-                                     "V|version",
-                                     "h|help",
-                                     "o|outputfile=s@")) {
+    if (not Getopt::Long::GetOptions(@options_list)) {
         print STDERR "Try `$0 --help' for more information.\n";
         exit(0);
     }
     $SIG{'__WARN__'} = undef;
-    &usage($0) if ($opt_h);
-    &hello() if ($opt_V);
+    usage($0) if ($opt_h);
+    hello() if ($opt_V);
 
     #   process command line arguments and
     #   read input file
@@ -81,15 +88,13 @@ sub setup {
         $fp->close;
     }
     else {
-        &usage;
+        usage();
     }
 
     #   add additional options
     $INPUT =~ s|^%!slice\s+(.*?)\n|push(@ARGV, split(' ', $1)), ''|egim;
-    if (not Getopt::Long::GetOptions("x|debug",
-                                     "v|version",
-                                     "o|outputfile=s@")) {
-        &usage;
+    if (not Getopt::Long::GetOptions(@options_list)) {
+        usage();
     }
     if ($#opt_o == -1) {
         @opt_o = ( "ALL:-" ); # default is all on stdout
@@ -102,6 +107,14 @@ sub setup {
     $CFG->{OPT} = {};    
     $CFG->{OPT}->{X} = $opt_v;        # option -v
     $CFG->{OPT}->{O} = [ @opt_o ];    # options -o
+    $CFG->{OPT}->{Y} = {
+        'u' => 0, 'w' => 0,
+        'z' => 0, 's' => 0,
+    };
+    $modifier = $opt_y;
+    foreach (qw(u w z s)) {
+        ($modifier =~ m/$_(\d+)/) and $CFG->{OPT}->{Y}->{$_} = $1;
+    }
     $CFG->{SLICE} = {};
     $CFG->{SLICE}->{SET} = {};       
     $CFG->{SLICE}->{SET}->{ASC} = {}; # slice set, represented in ASCII
