@@ -2,7 +2,8 @@
 package SliceTermParser;
 ;##
 ;##  slice_term.y -- YACC parser for slice terms
-;##  Copyright (c) 1997,1998 Ralf S. Engelschall. 
+;##  Copyright (c) 1997-2002 Ralf S. Engelschall. 
+;##  Copyright (c) 1999-2002 Denis Barbier.
 ;##
 
 package SliceTermParser;
@@ -268,10 +269,10 @@ yyloop: while(1)
     $p->{yym} = $yylen[$p->{yyn}];
     $p->{yyval} = $p->{yyvs}->[$p->{yyvsp}+1-$p->{yym}];
 if ($p->{yyn} == 1) {
-{ $p->{yyval} = &newvar($p->{yyvs}->[$p->{yyvsp}-0]); push(@OUT, "my ".$p->{yyval}." = \$CFG->{SLICE}->{SET}->{OBJ}->{'".$p->{yyvs}->[$p->{yyvsp}-0]."'}->Clone;"); }
+{ $p->{yyval} = newvar($p->{yyvs}->[$p->{yyvsp}-0]); push(@OUT, "my ".$p->{yyval}." = \$CFG->{SLICE}->{SET}->{OBJ}->{'".$p->{yyvs}->[$p->{yyvsp}-0]."'}->Clone;"); }
 }
 if ($p->{yyn} == 2) {
-{ $p->{yyval} = &newvar($p->{yyvs}->[$p->{yyvsp}-1]); push(@OUT, "my ".$p->{yyval}." = \$CFG->{SLICE}->{SET}->{OBJ}->{'NOV_".$p->{yyvs}->[$p->{yyvsp}-1]."'}->Clone;"); }
+{ $p->{yyval} = newvar($p->{yyvs}->[$p->{yyvsp}-1]); push(@OUT, "my ".$p->{yyval}." = \$CFG->{SLICE}->{SET}->{OBJ}->{'NOV_".$p->{yyvs}->[$p->{yyvsp}-1]."'}->Clone;"); }
 }
 if ($p->{yyn} == 3) {
 { $p->{yyval} = $p->{yyvs}->[$p->{yyvsp}-0]; push(@OUT, $p->{yyvs}->[$p->{yyvsp}-0]."->Complement(".$p->{yyvs}->[$p->{yyvsp}-0].");"); }
@@ -354,11 +355,14 @@ if ($p->{yyn} == 13) {
 #   create new set variable
 $tmpcnt = 0;
 sub newvar {
-    local ($name) = @_;
+    my ($name) = @_;
     my ($tmp);
 
     if ($main::CFG->{SLICE}->{SET}->{OBJ}->{"$name"} eq '') {
-        &main::printwarning("no such slice '$name'\n");
+        main::printwarning("no such slice '$name'\n") if $undef;
+        #    The $undef string is caught by caller, it is used
+        #    to trap warnings depending on the -y command line flag.
+        die $undef."\n" if $undef > 1;
         $main::CFG->{SLICE}->{SET}->{OBJ}->{"$name"} =
                 $main::CFG->{SLICE}->{SET}->{OBJ}->{DEF0}->Clone;
     }
@@ -411,7 +415,10 @@ sub yylex {
                 return ord('(');
             }
             else {
-                &main::error("no existing slice matches `$val'\n");
+                main::printwarning("no existing slice matches `$val'\n") if $wildcard;
+                #    The $wildcard string is caught by caller, it is used
+                #    to trap warnings depending on the -y command line flag.
+                die $wildcard."\n" if $wildcard > 1;
             }
         }
         return ($SLICE, $val);
@@ -432,18 +439,24 @@ sub yyerror {
 #
 #  The top-level function which gets called by the user
 #
-#  ($cmds, $var) = SliceTerm::Parse($term);
+#  ($cmds, $var) = SliceTerm::Parse($term, $status);
 #
 
 package SliceTerm;
 
 sub Parse {
-    local($str) = @_;
-    local($p, $var, $cmds);
+    local($str, $status) = @_;
+    my($p, $var, $cmds);
 
     @SliceTermParser::OUT = ();
+    $SliceTermParser::undef = $status->{u};
+    $SliceTermParser::wildcard = $status->{w};
     $p = SliceTermParser->new(\&SliceTermParser::yylex, \&SliceTermParser::yyerror, 0);
-    $var = $p->yyparse(*str);
+    eval {$var = $p->yyparse(*str);};
+    if ($@ =~ s/^(\d)$//) {
+        main::error("Execution stopped\n") if $1 > 2;
+        return ();
+    }
     $cmds = join("\n", @SliceTermParser::OUT) . "\n";
 
     return ($cmds, $var);
