@@ -1,7 +1,7 @@
 ##
 ##  slice_util.pl -- Utility functions
-##  Copyright (c) 1997-2000 Ralf S. Engelschall. 
-##  Copyright (c) 1999-2000 Denis Barbier.
+##  Copyright (c) 1997-2002 Ralf S. Engelschall. 
+##  Copyright (c) 1999-2002 Denis Barbier.
 ##
 
 package main;
@@ -25,7 +25,7 @@ sub printerror {
 sub error {
     my ($str) = @_;
 
-    &printerror($str);
+    printerror($str);
     exit(1);
 }
 
